@@ -1,5 +1,6 @@
 import functools
 
+import deprecation
 from flask import request
 from flask.wrappers import Response
 
@@ -9,12 +10,13 @@ from properly_util_python.properly_logging import ProperLogger
 from properly_util_python.user_auth import UserAuthHelper
 
 
+@deprecation.deprecated(deprecated_in="0.26.0", details="Ported to properly_util_python_private")
 def authorized(role, return_keys: list = []):
     def outer(func):
         @functools.wraps(func)
         def inner(*args, **kwargs):
             logger = ProperLogger("AuthDecorator")
-            logger.info("Authorizing request", {"request": request})
+            logger.debug("Authorizing request", {"request": request})
 
             user_auth_helper = UserAuthHelper(EnvironmentControlledDynamoHelper())
             event_object = request.environ.get("event")
@@ -29,18 +31,19 @@ def authorized(role, return_keys: list = []):
             logger.add_common_tags({"sub": sub, "provider": provider})
 
             # find the user
-            properly_user_id_caller = user_auth_helper.get_properly_id_from_user_verified_email(
+            properly_user = user_auth_helper.get_properly_user_from_user_verified_email(
                 email=user_auth["auth_email"]
             )
 
-            if properly_user_id_caller is None:
+            if properly_user is None:
                 logger.error("UserNotFound", "user not found")
                 return Response(response="{'error': 'user not found'}", status=403, mimetype="application/json")
- 
+
+            properly_user_id_caller = properly_user.get("id")
             logger.add_common_tags({"user_id": properly_user_id_caller})
 
             # verify the user record matches the Cognito information received
-            is_user_identity_correct = user_auth_helper.is_user_identity_correct(properly_user_id_caller, sub, provider)
+            is_user_identity_correct = user_auth_helper.check_user_identity(properly_user, sub, provider)
             if not is_user_identity_correct:
                 logger.error("MismatchedIdentity", "identity received doesn't match user record")
                 return Response(
@@ -50,13 +53,13 @@ def authorized(role, return_keys: list = []):
                 )
 
             # verify the user has the right roles for the operation
-            is_in_role_flag = user_auth_helper.is_user_in_role(properly_user_id_caller, role)
+            is_in_role_flag = user_auth_helper.check_user_in_role(properly_user, role)
 
             if not is_in_role_flag:
                 logger.error("MissingRole", "missing role")
                 return Response(response="{'error': 'missing role'}", status=403, mimetype="application/json")
 
-            logger.info("Authorization succeeded")
+            logger.debug("Authorization succeeded")
 
             if "user_id" in return_keys:
                 return func(*args, user_id=properly_user_id_caller, **kwargs)
